{
  config,
  pkgs,
  ...
}: {
  enable = true;
  package = pkgs.walker;
  runAsService = true;
  config = {
    activation_mode.labels = "neiotsra";
    as_window = false;
    disabled = [
      "bookmarks"
      "clipboard"
      "custom_commands"
      "translation"
      "websearch"
    ];
    builtins = {
      applications = {
        actions.enabled = true;
        context_aware = true;
        name = "applications";
        placeholder = "Applications";
        prioritize_new = true;
        refresh = true;
        show_generic = true;
        show_icon_when_single = true;
        show_sub_when_single = true;
        weight = 10;
      };
      calc = {
        icon = "accessories-calculator";
        min_chars = 4;
        name = "calc";
        placeholder = "Calculator";
        weight = 5;
      };
      clipboard = {
        image_height = 300;
        max_entries = 10;
        name = "clipboard";
        placeholder = "Clipboard";
        switcher_only = true;
        weight = 5;
      };
      commands = {
        icon = "utilities-terminal";
        name = "commands";
        placeholder = "Commands";
        switcher_only = true;
        weight = 8;
      };
      custom_commands = {
        icon = "utilities-terminal";
        name = "custom_commands";
        placeholder = "Custom Commands";
        weight = 5;
      };
      dmenu = {
        name = "dmenu";
        placeholder = "Dmenu";
        switcher_only = true;
        weight = 5;
      };
      emojis = {
        history = true;
        name = "emojis";
        placeholder = "Emojis";
        switcher_only = true;
        typeahead = true;
        weight = 5;
      };
      finder = {
        concurrency = 8;
        icon = "folder";
        ignore_gitignore = true;
        name = "finder";
        placeholder = "Finder";
        refresh = true;
        switcher_only = true;
        weight = 5;
      };
      runner = {
        generic_entry = false;
        history = true;
        icon = "utilities-terminal";
        name = "runner";
        placeholder = "Runner";
        refresh = true;
        typeahead = true;
        weight = 5;
      };
      ssh = {
        history = true;
        icon = "preferences-system-network";
        name = "ssh";
        placeholder = "SSH";
        refresh = true;
        switcher_only = true;
        weight = 5;
      };
      switcher = {
        name = "switcher";
        placeholder = "Switcher";
        prefix = "/";
        weight = 5;
      };
      websearch = {
        icon = "applications-internet";
        name = "websearch";
        placeholder = "Websearch";
        weight = 5;
      };
      windows = {
        icon = "view-restore";
        name = "windows";
        placeholder = "Windows";
        weight = 10;
      };
    };
    disable_click_to_close = false;
    force_keyboard_focus = true;
    list = {
      max_entries = 50;
      show_initial_entries = true;
      single_click = true;
    };
    search = {
      delay = 0;
      force_keyboard_focus = true;
      history = true;
      placeholder = "Search...";
    };
  };
  theme = {
    layout = {
      ui = {
        anchors = {
          bottom = false;
          left = false;
          right = false;
          top = false;
        };
        window = {
          h_align = "center";
          v_align = "center";
          box = {
            width = 450;
            h_align = "center";
            v_align = "center";
            # spacing = 12;
            orientation = "vertical";
            search = {
              margins = {
                start = 8;
                top = 8;
                end = 8;
                bottom = 0;
              };
              h_align = "top";
            };
            scroll = {
              overlay_scrolling = true;
              list = {
                margins = {
                  bottom = 8;
                  top = 4;
                  start = 8;
                  end = 8;
                };
                item = {
                  icon.theme = "${config.gtk.iconTheme.name}";
                  spacing = 4;
                  activation_label = {
                    x_align = 0.5;
                    y_align = 0.5;
                    width = 32;
                  };
                  text = {
                    h_align = "start";
                    h_expand = true;
                    revert = true;
                    wrap = true;
                  };
                };
              };
            };
          };
        };
      };
    };
    style = let
      inherit (config.lib.stylix) colors;
    in ''
      @define-color base00 #${colors.base00};
      @define-color base01 #${colors.base01};
      @define-color base02 #${colors.base02};
      @define-color base03 #${colors.base03};
      @define-color base04 #${colors.base04};
      @define-color base05 #${colors.base05};
      @define-color base06 #${colors.base06};
      @define-color base07 #${colors.base07};
      @define-color base08 #${colors.base08};
      @define-color base09 #${colors.base09};
      @define-color base0A #${colors.base0A};
      @define-color base0B #${colors.base0B};
      @define-color base0C #${colors.base0C};
      @define-color base0D #${colors.base0D};
      @define-color base0E #${colors.base0E};
      @define-color base0F #${colors.base0F};

      #window,
      #box,
      #search,
      #password,
      #input,
      #typeahead,
      #spinner,
      #list,
      child,
      scrollbar,
      slider,
      #item,
      #text,
      #label,
      #sub,
      #activationlabel {
        all: unset;
      }

      #window {
        background: @base00;
        color: @base05;
        border-radius: 20px;
        border: 3px solid @base0D;
      }

      #box {
        background: @base00;
      }

      #search {
        background: @base01;
        border-radius: 12px 12px 6px 6px;
        padding: 8px;
      }

      #password,
      #input,
      #typeahead {
        background: none;
        box-shadow: none;
        border-radius: 12px;
      }

      #input > *:first-child,
      #typeahead > *:first-child {
        margin-right: 12px;
        border-radius: 0px;
      }

      #typeahead {
        color: @base05;
      }

      #input placeholder {
        opacity: 0.5;
      }

      #list {
        padding: 8px;
        border-radius: 6px 6px 12px 12px;
        background: @base01;
      }

      child {
        box-shadow: none;
      }

      child:selected,
      child:hover {
        box-shadow: none;
        border-radius: 8px;
        background: @base02;
      }

      #item {
        padding: 4px;
      }

      #sub {
        font-size: smaller;
        opacity: 0.5;
      }

      #activationlabel {
        opacity: 0.5;
      }

      .activation #activationlabel {
        opacity: 1;
        color: @base05;
      }
    '';
  };
}
